# Package should be built in nonfree only, as it only provides features for nvidia390

%define driver  nvidia390

%define real_name primus
%define libname %mklibname %{name}
%global __provides_exclude \\.so

Name:           primus-nvidia390
Version:        0.2
Release:        %mkrel 4
Summary:        Minimalistic and efficient OpenGL offloading for Bumblebee-nvidia390
Group:          System/Kernel and hardware
License:        ISC
URL:            https://github.com/amonakov/primus
Source0:        https://github.com/amonakov/primus/archive/v%{version}/%{real_name}-%{version}.tar.gz
Patch1:         primus-0.1-mga-libgl-nvidia390.patch
Patch2:         primus-git-build-with-ldflags.patch
Patch3:         primus-0.2-mga-libglfork-dl-linking.patch
# from Gentoo
Patch4:         primus-0.2-libglvnd-workaround.patch

ExclusiveArch:  %{ix86} x86_64

BuildRequires:  pkgconfig(gl)
BuildRequires:  pkgconfig(x11)

Requires:       %{libname} = %{version}-%{release}

%ifarch x86_64
Recommends:     lib%{name} = %{version}-%{release}
%endif

Conflicts:      primus
Conflicts:      primus-nvidia

%description
Primus is a shared library that provides OpenGL and GLX APIs and
implements low-overhead local-only client-side OpenGL offloading via GLX
forking, similar to VirtualGL. It intercepts GLX calls and redirects GL
rendering to a secondary X display, presumably driven by a faster GPU.
On swapping buffers, rendered contents are read back using a PBO and
copied onto the drawable it was supposed to be rendered on in the first
place.

This package provides primusrun script patched against the %{driver} driver
for GeForce 420 and later cards.

%files
%doc README.md technotes.md
%{_bindir}/primusrun
%{_mandir}/man1/primusrun.1*
%{_sysconfdir}/bash_completion.d/%{real_name}

#--------------------------------------------------------------------

%package -n     %{libname}
Summary:        Shared library for Primus nvidia390
Group:          System/Libraries
Requires:       %{name}

Conflicts:      libprimus
Conflicts:      lib64primus

%description -n %{libname}
Libraries injected by Primus into applications that are ran through it.
Lib packages allow installing 32 and 64 bit libraries at the same time.

%files -n       %{libname}
%dir %{_libdir}/%{real_name}
%{_libdir}/%{real_name}/libGL.so.1

#--------------------------------------------------------------------

%prep
%setup -qn %{real_name}-%{version}
%autopatch -p1

%build
%set_build_flags
%make_build \
  LIBDIR=%{_lib} \
  PRIMUS_libGLa=%{_libdir}/libGLX_nvidia.so.0 \
  PRIMUS_libGLd=%{_libdir}/libGLX.so.0

%install
install -Dm755 primusrun %{buildroot}%{_bindir}/primusrun
install -Dm755 %{_lib}/libGL.so.1 %{buildroot}%{_libdir}/%{real_name}/libGL.so.1
install -Dm644 primusrun.1 %{buildroot}%{_mandir}/man1/primusrun.1
install -Dm644 primus.bash-completion %{buildroot}%{_sysconfdir}/bash_completion.d/%{real_name}


%changelog
* Thu Feb 04 2021 daviddavid <daviddavid> 0.2-4.mga8
+ Revision: 1674796
- fix nvidia and gl libraries path
- add a libglvnd workaround from Gentoo

* Fri Feb 21 2020 umeabot <umeabot> 0.2-3.mga8.nonfree
+ Revision: 1548643
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%setup_compile_flags

* Fri Mar 29 2019 daviddavid <daviddavid> 0.2-2.mga7.nonfree
+ Revision: 1381000
- drop aarch64 and arm support, nvidia390 driver is only available on x86 and x86_64 arches

* Thu Mar 28 2019 daviddavid <daviddavid> 0.2-1.mga7.nonfree
+ Revision: 1380797
- initial package primus-nvidia390

